# 
# /*
#  * *********** WARNING **************
#  * This file generated by My::WrapXS/2.17
#  * Any changes made here will be lost
#  * ***********************************
#  * 1. /usr/local/libdata/perl5/site_perl/ExtUtils/XSBuilder/WrapXS.pm:52
#  * 2. /usr/local/libdata/perl5/site_perl/ExtUtils/XSBuilder/WrapXS.pm:2068
#  * 3. Makefile.PL:193
#  */
# 


package APR::Request::Apache2;
require DynaLoader ;

use strict;
use warnings FATAL => 'all';

use vars qw{$VERSION @ISA} ;

push @ISA, 'DynaLoader' ;
$VERSION = '2.17';
bootstrap APR::Request::Apache2 $VERSION ;

use APR::Request;
push @ISA, "APR::Request";


1;
__END__
